@@ -3,9 +3,9 @@ package com.sun.tools.javac.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "11.0.30+7" },
-            { "jdk", "11.0.30" },
-            { "release", "11.0.30" },
+            { "full", "21.0.5+11-LTS" },
+            { "jdk", "21.0.5" },
+            { "release", "21.0.5" },
         };
     }
 }
